﻿using Eto.Forms;
using Rhino;
using Rhino.Runtime;
using Rhino.UI;
using Rhino.UI.Controls;
using System;
using System.Diagnostics;
using System.Runtime.InteropServices;

namespace SamplePanel
{
  /// <summary>
  /// SamplePanel panel
  /// </summary>
  [Guid("45b28988-926e-43b9-a1dc-473f7141f6dc")]
  public class SampleDocumentPanel : Panel, IPanel, IHelp
  {
    // The panel's persistent id
    public static Guid PanelId => typeof(SampleDocumentPanel).GUID;

    // The panel's view model, set by the constructor
    private SampleDocumentPanelViewModel ViewModel { get; set; }

    /// <summary>
    /// Public constructor
    /// </summary>
    public SampleDocumentPanel(uint documentSerialNumber)
    {
      var doc = RhinoDoc.FromRuntimeSerialNumber(documentSerialNumber);
      ViewModel = doc?.RuntimeData.GetValue(typeof(SampleDocumentPanelViewModel), rhinoDoc => new SampleDocumentPanelViewModel(rhinoDoc.RuntimeSerialNumber));
      if (null == ViewModel)
        return;

      DataContext = ViewModel;

      Content = HostUtils.RunningOnWindows
        ? CreatePanelLayoutWin()
        : CreatePanelLayoutMac();
    }

    /// <summary>
    /// Creates the panel's table layout for Windows
    /// </summary>
    private TableLayout CreatePanelLayoutWin()
    {
      var label = new Label();
      label.TextBinding.BindDataContext((SampleDocumentPanelViewModel m) => m.DocumentLabel);

      return new RhinoPanelTableLayout
      {
        Rows =
        {
          label,
          null
        }
      };
    }

    /// <summary>
    /// Creates the panel's table layout for Mac
    /// </summary>
    private TableLayout CreatePanelLayoutMac()
    {
      return CreatePanelLayoutWin();
    }

    #region IPanel interface

    public void PanelClosing(uint documentSerialNumber, bool onCloseDocument)
    {
      Debug.WriteLine("Sample panel closing");
    }

    public void PanelHidden(uint documentSerialNumber, ShowPanelReason reason)
    {
      Debug.WriteLine("Sample panel hidden");
    }

    public void PanelShown(uint documentSerialNumber, ShowPanelReason reason)
    {
      Debug.WriteLine("Sample panel shown");
    }

    #endregion

    #region IHelp interface

    public string HelpUrl => string.Empty;

    #endregion
  }
}
