﻿using Rhino;
using Rhino.FileIO;
using Rhino.PlugIns;
using Rhino.UI;
using System;

namespace SamplePanel
{
  /// <summary>
  /// SamplePanel plug-in
  /// </summary>
  public class SamplePanelPlugIn : PlugIn
  {
    public SamplePanelPlugIn()
    {
      Instance = this;
    }

    /// <summary>
    /// Gets the one and only SamplePanelPlugIn object
    /// </summary>
    public static SamplePanelPlugIn Instance
    {
      get; private set;
    }

    /// <summary>
    /// PlugIn.OnLoad override
    /// </summary>
    protected override LoadReturnCode OnLoad(ref string errorMessage)
    {
      var icon = DrawingUtilities.IconFromResource("SamplePanel.Resources.SamplePanel.ico", GetType().Assembly);
      Panels.RegisterPanel(this, typeof(SampleDocumentPanel), "Sample", icon, PanelType.PerDoc);
      return LoadReturnCode.Success;
    }

    /// <summary>
    /// PlugIn.ShouldCallWriteDocument override
    /// </summary>
    protected override bool ShouldCallWriteDocument(FileWriteOptions options)
    {
      return true;
    }

    /// <summary>
    /// PlugIn.WriteDocument override
    /// </summary>
    protected override void WriteDocument(RhinoDoc doc, BinaryArchiveWriter archive, FileWriteOptions options)
    {
      base.WriteDocument(doc, archive, options);
    }

    public delegate void DocumentDataReadHandler(object sender, DocumentDataReadEventArgs args);
    public event DocumentDataReadHandler ReadDocumentData;

    /// <summary>
    /// PlugIn.ReadDocument override
    /// </summary>
    protected override void ReadDocument(RhinoDoc doc, BinaryArchiveReader archive, FileReadOptions options)
    {
      if (null != ReadDocumentData)
      {
        var args = new DocumentDataReadEventArgs(doc.RuntimeSerialNumber);
        ReadDocumentData(this, args);
      }
    }
  }

  /// <summary>
  /// EventArgs-inherited class
  /// </summary>
  public class DocumentDataReadEventArgs : EventArgs
  {
    public uint DocumentSerialNumber { get; private set; }

    public DocumentDataReadEventArgs(uint documentSerialNumber)
    {
      DocumentSerialNumber = documentSerialNumber;
    }
  }
}